% 2d partial FFT matrix selecting rows: constructor
%
% A = fftline2mat(sz,id,complex)
%
%  sz      [1,2]: size of the image to transform
%  id      [1,p]: row indices to keep, default id=1:sz(1)
%  complex [1,1]: flag saying whether we have complex output, default is true
%
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 July 15
%
% The transform is NOT centered.

function A = fftline2mat(sz,id,complex)

  A.imsz = sz; if numel(A.imsz) == 1, A.imsz = A.imsz*[1,1]; end    % image size

  if nargin>1
    id(id<1) = 1; id(id>A.imsz(1)) = A.imsz(1);              % put into interval
    A.id = fix(id(:));                      % subset of 1..imsz(1), double is ok
  else
    A.id = 1:A.sz(1);
  end
  sz = [numel(A.id)*A.imsz(2),prod(A.imsz)];                       % matrix size
  if nargin>2
    A.complex = complex;
  else
    A.complex = true;
  end
  A.sz = sz; A.ctransp = 0; A = class(A,mfilename);                  % [generic]