% P = potExpPower(s,alpha) - Exponential power family potential
%
% pott(s) = exp(-|s|^alpha) with shape parameter alpha>0
%
%   See also POTFUNCTIONS.M.
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 July 14

function P = potExpPower(s,alpha)

P = zeros(numel(s),4);
P(:,1) =                 -abs(s).^ alpha;                        % log potential
P(:,2) = -alpha*sign(s) .*abs(s).^(alpha-1);   % 1st derivative of log potential
P(:,3) = -alpha*(alpha-1)*abs(s).^(alpha-2);   % 2nd derivative of log potential