% P = potSech2(s) - Sech-squared potential (Logistic distribution)
%
% pot(s) = 1 / cosh(s)²
%
%   See also POTFUNCTIONS.M.
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 July 21

function P = potSech2(s)

P = zeros(numel(s),4);
a = exp(-2*abs(s));      % always between 0 and 1 and therefore safe to evaluate
P(:,1) = -2*(abs(s) + log(1+a) - log(2));     % log potential, -2*log( cosh(s) )
b = 2*a./(1+a);
P(:,2) = -2*sign(s).*(1-b);                    % 1st derivative of log potential
P(:,3) = -4*b./(1+a);                          % 2nd derivative of log potential