% P = potT(s,nu) - Student's t potential
%
% pot(s) = ( 1 + s²/nu )^(-nu/2-1/2) with nu>0 degrees of freedom
%
%   See also POTFUNCTIONS.M.
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 July 14

function P = potT(s,nu)

P = zeros(numel(s),4);
ss = s.*s;
P(:,1) = - (nu+1)*log( 1+ss./nu )/2;                             % log potential
a = ss+nu;
P(:,2) = - (nu+1)*s./a;                        % 1st derivative of log potential
P(:,3) =   (nu+1)*(ss-nu)./(a.*a);             % 2nd derivative of log potential