% A potential pot(s) is a scalar positive and strongly super Gaussian 
% function IR -> IR_+ that can be symmetrised i.e. there is a number b 
% such that f(s) = pot(s)*exp(-b*s) is even.
%
%   P = pot(s,theta) where theta contains additional parameters
%
% The return argument is a matrix of size [px4] where the columns do have the 
% following meaning:
%   lp = P(:,1), dlp = P(:,2), d2lp = P(:,3), b = P(:,4), where
%
%   (i)   lp(s)   = log( pot(s) ),
%   (ii)  dlp(s)  = d   lp(s) / ds,
%   (iii) d2lp(s) = d^2 lp(s) / ds^2, and
%   (iv)  f(s) = pot(s)*exp(-b*s) is symmetric, i.e. f(s) = f(-s).
%
% We can split the matrix P by the command 
%   [lp,dlp,d2lp,b] = col(P).
% 
% Currently, we have implemented in pot/pot<NAME>.m
%   Gaussian:                potGauss(s)       = exp(-s^2/2),
%   Sech-squared:            potSech2(s)       = 1 / cosh(s)^2,
%   Laplace:                 potLaplace(s)     = exp(-abs(s)),
%   Student's t, nu>0:       potT(s,nu)        = (1 + s^2/nu)^(-nu/2-1/2),
%   Exponential power, al>0: potExpPower(s,a)  = exp(-|s|^al), and
%   Logistic function:       potLogistic(s)    = 1/(1+exp(-s)).
%
% Examples:
% >>  s=0.3; potLogistic(s)
% >>  s=2.7; nu=3; potT(s,nu)
%
%   See also PENFUNCTIONS.M.
%
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 July 27
